==> openvas-client_1.0.3.orig.tar.gz: openvas-client-1.0.3/nessus/nessus.h <==
/* NessusClient -- the Nessus Client
 * Copyright (C) 1998 Renaud Deraison
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * In addition, as a special exception, Renaud Deraison
 * gives permission to link the code of this program with any
 * version of the OpenSSL library which is distributed under a
 * license identical to that listed in the included COPYING.OpenSSL
 * file, and distribute linked combinations including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * this file, you may extend this exception to your version of the
 * file, but you are not obligated to do so.  If you do not wish to
 * do so, delete this exception statement from your version.
 */

#ifndef _NESSUSC_NESSUS_H
#define _NESSUSC_NESSUS_H

/* The default port assigned to nessus by the iana is 1241, see
   http://www.isi.edu/in-notes/iana/assignments/port-numbers */
#ifdef _WIN32
#ifndef NESIANA_PORT
#define NESIANA_PORT 1241
#endif
#endif

#define DEFAULT_SERVER "localhost"
#define PROTO_NAME "< NTP/1.2 >< plugins_cve_id plugins_version plugins_bugtraq_id plugins_xrefs timestamps dependencies %s >\n"
#ifdef NESSUS_ON_SSL
# define SSL_VER_DEF_NAME	"TLSv1"
# define SSL_VER_DEF_METH	TLSv1_client_method
#endif /* NESSUS_ON_SSL */

#ifdef _CYGWIN_
extern char * NESSUS_RCFILE;
extern int init_directories;
#else
#define NESSUS_RCFILE     "~/.openvasrc"
#endif


#include "context.h"

char * connect_to_nessusd(struct context *);

#endif

==> openvas-client_1.0.4.orig.tar.gz: openvas-client-1.0.4/nessus/nessus.h <==
/* NessusClient -- the Nessus Client
 * Copyright (C) 1998 Renaud Deraison
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * In addition, as a special exception, Renaud Deraison
 * gives permission to link the code of this program with any
 * version of the OpenSSL library which is distributed under a
 * license identical to that listed in the included COPYING.OpenSSL
 * file, and distribute linked combinations including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * this file, you may extend this exception to your version of the
 * file, but you are not obligated to do so.  If you do not wish to
 * do so, delete this exception statement from your version.
 */

#ifndef _NESSUSC_NESSUS_H
#define _NESSUSC_NESSUS_H

/* The default port assigned to nessus by the iana is 1241, see
   http://www.isi.edu/in-notes/iana/assignments/port-numbers */
#ifdef _WIN32
#ifndef NESIANA_PORT
#define NESIANA_PORT 1241
#endif
#endif

#define DEFAULT_SERVER "localhost"
#define PROTO_NAME "< NTP/1.2 >< plugins_cve_id plugins_version plugins_bugtraq_id plugins_xrefs timestamps dependencies %s >\n"
#define PROTO_NAME_OTP "< OTP/1.0 >< plugins_cve_id plugins_version plugins_bugtraq_id plugins_xrefs timestamps dependencies %s >\n"
# define SSL_VER_DEF_NAME	"TLSv1"
# define SSL_VER_DEF_METH	TLSv1_client_method

#ifdef _CYGWIN_
extern char * NESSUS_RCFILE;
extern int init_directories;
#else
#define NESSUS_RCFILE     "~/.openvasrc"
#endif


#include "context.h"

char * connect_to_nessusd(struct context *);

#endif
